md_code_and_df: Return the code and data frame output in markdown format

Description Usage Arguments Value Examples

View source: R/md_code_and_df.R

Description

Return the code and data frame output in markdown format

Usage

1
md_code_and_df(text = NULL, is_paste = TRUE)

Arguments

text

The R code to execute, if text is NULL by default, the text capture the clipboard.

is_paste

Logical, by default, TRUE, whether or not to paste the output on the clipboard.

Value

The text containing code and data frame output.

Examples

1
md_code_and_df("head(mtcars)", is_paste = FALSE)

JiaxiangBU/add2reprex documentation built on Jan. 30, 2020, 12:20 a.m.