Description Usage Arguments Value Examples
View source: R/md_code_and_df.R
Return the code and data frame output in markdown format
1 | md_code_and_df(text = NULL, is_paste = TRUE)
|
text |
The R code to execute, if text is |
is_paste |
Logical, by default, |
The text containing code and data frame output.
1 | md_code_and_df("head(mtcars)", is_paste = FALSE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.